@@ -160,10 +160,10 @@ class SlappResponseObject:
             # Plus the bracket must have had placements in it (a winning team)
             brackets = [b for b in self.placements_for_players[p.guid.__str__()][source_id] if
                         (
-                                b.name.startswith("Alpha") or
-                                b.name.startswith("Beta") or
-                                b.name.startswith("Gamma") or
-                                b.name.startswith("Top Cut")
+                                "Alpha" in b.name or
+                                "Beta" in b.name or
+                                "Gamma" in b.name or
+                                "Top Cut" in b.name
                         ) and 1 in b.placements.players_by_placement]
             for bracket in brackets:
                 for placement in bracket.placements.players_by_placement:
@@ -183,23 +183,23 @@ class SlappResponseObject:
                 continue
 
             if current_best is None:
-                current_best = (placement[0], placement[1], placement[2])
+                current_best = placement
             else:
-                is_same_comparison = (placement[1].startswith("Alpha") and current_best[1].startswith("Alpha")) or \
-                                     (placement[1].startswith("Beta") and current_best[1].startswith("Beta")) or \
-                                     (placement[1].startswith("Gamma") and current_best[1].startswith("Gamma")) or \
-                                     (placement[1].startswith("Alpha") and current_best[1].startswith("Top Cut")) or \
-                                     (placement[1].startswith("Top Cut") and current_best[1].startswith("Alpha"))
+                is_same_comparison = ("Alpha" in placement[1] and "Alpha" in current_best[1]) or \
+                                     ("Beta" in placement[1] and "Beta" in current_best[1]) or \
+                                     ("Gamma" in placement[1] and "Gamma" in current_best[1]) or \
+                                     ("Alpha" in placement[1] and "Top Cut" in current_best[1]) or \
+                                     ("Top Cut" in placement[1] and "Alpha" in current_best[1])
                 if is_same_comparison:
                     # If lower place (i.e. did better)
                     if placement[0] < current_best[0]:
                         current_best = placement
                 else:
-                    if placement[1].startswith("Alpha") or placement[1].startswith("Top Cut"):
+                    if "Alpha" in placement[1] or "Top Cut" in placement[1]:
                         # Better than the current best's bracket
                         current_best = placement
-                    elif placement[1].startswith("Beta"):
-                        if not current_best[1].startswith("Alpha"):
+                    elif "Beta" in placement[1]:
+                        if "Alpha" not in current_best[1]:
                             # Better than the current best's bracket (gamma)
                             current_best = placement
                     # else gamma but this isn't better than the valid bracket names already tested
